/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import mdx from './button.mdx';

export default {
  title: 'Product Subsystem/Components/Button',
  parameters: {
    docs: {
      page: mdx,
    },
  },
  argTypes: {
    variant: {
      control: {
        type: 'select',
        options: [
          'default',
          'base',
          'brand',
          'brand-outline',
          'inverse',
          'success',
          'destructive',
          'destructive-text',
        ],
      },
      defaultValue: 'default',
    },
    size: {
      control: { type: 'select', options: ['default', 'stretch'] },
      defaultValue: 'default',
    },
    disabled: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    label: {
      control: {
        type: 'text',
      },
      defaultValue: 'Button',
    },
  },
};

const TextTemplate = (args) => `
<div ${
  args.variant === 'inverse' ? 'style="padding: 0.5rem; background: var(--sds-g-color-brand-inverse-2);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    ${args.label}
  </slds-button>
</div>
`;
export const Text = TextTemplate.bind({});

const TextAndIconTemplate = (args) => `
<div ${
  args.variant === 'inverse' ? 'style="padding: 0.5rem; background: var(--sds-g-color-brand-inverse-2);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    ${args.label}
    <slds-icon icon-name="utility:download" slot="end"></slds-icon>
  </slds-button>
</div>
`;
export const TextAndIcon = TextAndIconTemplate.bind({});

const IconTemplate = (args) => `
<div ${
  args.variant === 'inverse' ? 'style="padding: 0.5rem; background: var(--sds-g-color-brand-inverse-2);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    <span>↓</span>
  </slds-button>
</div>
`;
export const Icon = IconTemplate.bind({});
